@@ -1,4 +1,8 @@
-from django.conf.urls.defaults import patterns, url
+# -*- coding: utf-8 -*-
+try:
+    from django.conf.urls import patterns, url
+except ImportError:
+    from django.conf.urls.defaults import patterns, url
 
 
 urlpatterns = patterns('blackhole.views',
